ArchitectureIntelligenceEngine class

Analyzes an ArchitectureGraph for structural problems.

Detects: God Component, State Explosion, High Coupling, Improper Async Pattern, Logic Leakage, and Circular Dependencies.

Constructors

ArchitectureIntelligenceEngine(ArchitectureGraph graph)
Creates an engine that will analyze graph.

Properties

graph ArchitectureGraph
The graph to analyze.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyze() List<ArchitectureSmell>
Runs all smell detectors and returns every finding.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited