autoMergeState property
When true, multi-field state is automatically collapsed into a single state class.
Implementation
final bool autoMergeState;
When true, multi-field state is automatically collapsed into a single state class.
final bool autoMergeState;