DependencyChecker class

Utility for detecting and reporting circular dependencies in an ArchitectureGraph.

Constructors

DependencyChecker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkCircularDependencies(ArchitectureGraph graph) List<String>
Detects circular dependencies in the architecture graph. Returns a list of human-readable warning strings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited