GovernanceViolation class

A breach of a configurable architecture contract.

Constructors

GovernanceViolation({required String nodeId, required String ruleName, required String message, String severity = 'error'})
Creates a GovernanceViolation for nodeId.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the breach.
final
nodeId String
ID of the offending component in the ArchitectureGraph.
final
ruleName String
Name of the rule that was broken, e.g. 'Forbidden Dependency'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String
Severity level: 'warning' or 'error'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited