ImportManager class
Manages import statements in migrated Dart files.
Adds flutter_riverpod when Riverpod consumer symbols are present,
adds riverpod_annotation when @riverpod annotations or .g.dart part
directives are present, and optionally removes the legacy provider import
when it is no longer needed.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processImports(
String content, {bool cleanProvider = true}) → String - Injects required Riverpod imports and optionally removes the legacy Provider import.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited