PackageInfo class

Metadata about a single Dart package discovered under the monorepo root.

Constructors

PackageInfo({required String name, required String rootPath})
Creates a PackageInfo.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Dart package name from pubspec.yaml.
final
rootPath String
Absolute path to the package root directory.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited