GraphVisualizationSnapshot class

Immutable summary produced by ProviderVisualizer.createSnapshot.

Constructors

GraphVisualizationSnapshot({required String mermaid, required int nodeCount, required int edgeCount, required int cycleCount, required int logicUnitCount, required int widgetCount})
Creates a GraphVisualizationSnapshot.
const

Properties

cycleCount int
Number of detected dependency cycles.
final
edgeCount int
Total number of dependency edges in the graph.
final
hashCode int
The hash code for this object.
no setterinherited
logicUnitCount int
Number of logic-unit (notifier/service) nodes.
final
mermaid String
Mermaid diagram source representing the full graph.
final
nodeCount int
Total number of component nodes in the graph.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetCount int
Number of widget nodes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited