ProviderVisualizer class

Generates Mermaid diagrams and summary statistics from an ArchitectureGraph.

Constructors

ProviderVisualizer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSnapshot(ArchitectureGraph graph) GraphVisualizationSnapshot
Builds a GraphVisualizationSnapshot for graph.
describeSummary(ArchitectureGraph graph) String
Returns a one-line summary of the key graph metrics.
generateMermaid(ArchitectureGraph graph) String
Generates a Mermaid graph TD diagram string for graph.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveGraph(String targetPath, String content) → void
Writes content to architecture_graph.mmd inside targetPath.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited