TextEdit class

A single in-place source replacement produced by RiverpodTransformer.

Constructors

TextEdit(int offset, int length, String replacement)
Creates a TextEdit.

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Number of bytes to replace (0 for a pure insertion).
final
offset int
Byte offset where the replacement starts.
final
replacement String
The text to write at offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited