DependencyEdge class

A directed relationship between two nodes in the ArchitectureGraph.

Constructors

DependencyEdge({required String fromId, required String toId, required RelationshipType type, int offset = 0})
Creates a DependencyEdge between fromId and toId.

Properties

fromId String
ID of the source component.
final
hashCode int
The hash code for this object.
no setterinherited
offset int
Source offset where the relationship originates.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toId String
ID of the target component.
final
type RelationshipType
Semantic type of the dependency.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited