ConsumerNode class

IR node for a Consumer or Builder widget that watches a provider.

Inheritance

Constructors

ConsumerNode({required String consumedClass, int? builderOffset, int? builderLength, int? childOffset, int? childLength, required String filePath, required int offset, required int length})
Creates a ConsumerNode.

Properties

builderLength int?
Source length of the builder: argument, if present.
final
builderOffset int?
Source offset of the builder: argument, if present.
final
childLength int?
Source length of the child: argument, if present.
final
childOffset int?
Source offset of the child: argument, if present.
final
consumedClass String
Name of the consumed provider type, e.g. 'Counter'.
final
filePath String
Absolute path to the source file that contains this node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
Byte length of the node within the source file.
finalinherited
offset int
Byte offset of the node's start within the source file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited