ContextSelectNode class
IR node for a context.select<T, R>(fn) call site.
Maps to ref.watch(tProvider.select(fn)) in Riverpod.
- Inheritance
-
- Object
- ProviderNode
- ContextSelectNode
Constructors
- ContextSelectNode({required String consumedClass, required String selectorSnippet, required String filePath, required int offset, required int length})
- Creates a ContextSelectNode.
Properties
- consumedClass → String
-
Name of the watched provider type, e.g.
'Counter'.final - filePath → String
-
Absolute path to the source file that contains this node.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Byte length of the node within the source file.
finalinherited
- offset → int
-
Byte offset of the node's start within the source file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectorSnippet → String
-
Source text of the selector function passed to
context.select.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited