FieldInfo class

A single field captured from a class declaration.

Constructors

FieldInfo({required String rawName, String type = 'dynamic', String? initializer})
Creates a FieldInfo.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initializer String?
Source text of the initializer expression.
final
publicName String
Public name (leading _ stripped), e.g. count.
no setter
rawName String
Raw source name (may have leading _), e.g. _count.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Dart type as source text, e.g. int, String, List<Todo>.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited