ProviderOfNode class

IR node for a context.watch, context.read, or Provider.of access.

Inheritance

Constructors

ProviderOfNode({required String consumedClass, bool isInBuildMethod = false, bool isMethodCall = false, required String filePath, required int offset, required int length})
Creates a ProviderOfNode.

Properties

consumedClass String
Name of the consumed provider type.
final
filePath String
Absolute path to the source file that contains this node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isInBuildMethod bool
True when the access is inside a build() method (reactive watch context).
final
isMethodCall bool
True when the result is immediately used for a method call (→ .notifier).
final
length int
Byte length of the node within the source file.
finalinherited
offset int
Byte offset of the node's start within the source file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited