SelectorNode class

IR node for a Selector widget that listens to a derived slice of state.

Inheritance

Constructors

SelectorNode({required String consumedClass, required String selectedType, required String selectorSnippet, int? builderOffset, int? builderLength, int? childOffset, int? childLength, required String filePath, required int offset, required int length})
Creates a SelectorNode.

Properties

builderLength int?
Source length of the builder: argument, if present.
final
builderOffset int?
Source offset of the builder: argument, if present.
final
childLength int?
Source length of the child: argument, if present.
final
childOffset int?
Source offset of the child: argument, if present.
final
consumedClass String
Name of the watched provider type.
final
filePath String
Absolute path to the source file that contains this node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
Byte length of the node within the source file.
finalinherited
offset int
Byte offset of the node's start within the source file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedType String
Dart type of the selected sub-value, e.g. 'int'.
final
selectorSnippet String
Source text of the selector lambda, e.g. '(s) => s.count'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited