CustomTransformer class abstract

Applies source transformations for nodes detected by a CustomAdapter.

Constructors

CustomTransformer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(String source, List<ProviderNode> nodes) String
Returns the rewritten source, applying transformations for nodes.

Operators

operator ==(Object other) bool
The equality operator.
inherited