MigrationPlugin class abstract

Base interface that every plugin package must implement.

Constructors

MigrationPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Unique human-readable identifier for this plugin.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
Semantic version string of the plugin.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited