Todo class

Constructors

Todo({required String id, required String title, bool isCompleted = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isCompleted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

copyWith({String? id, String? title, bool? isCompleted}) Todo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited