ArchitectureSmell class
A detected structural problem in the architecture graph.
Severities: 'info', 'warning', 'error'.
Constructors
- ArchitectureSmell({required String nodeId, required String name, required String description, String severity = 'warning'})
-
Creates an ArchitectureSmell for the component identified by
nodeId.
Properties
- description → String
-
Explanation of why the smell was flagged and its impact.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Human-readable smell name, e.g.
'God Component'.final - nodeId → String
-
ID of the offending component in the ArchitectureGraph.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → String
-
Severity level:
'info','warning', or'error'.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited