DependencyUpdateResult class
Result of a DependencyManager.updateDependencies call.
Constructors
-
DependencyUpdateResult({required List<
String> added, required List<String> commented, bool pubGetSucceeded = false}) -
Creates a DependencyUpdateResult.
const
Properties
-
added
→ List<
String> -
Packages that were added to
pubspec.yaml.final -
commented
→ List<
String> -
Packages that were commented out in
pubspec.yaml.final - hasChanges → bool
-
True when any packages were added or commented.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- pubGetSucceeded → bool
-
True when
flutter pub getcompleted successfully after the update.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited