DriftReport class
The difference between the current analysis and a prior DriftSnapshot.
Constructors
Properties
- comparedAt → DateTime
-
Timestamp of the prior snapshot this report was compared against.
final
- hasChanges → bool
-
True when any smells or violations changed since the prior snapshot.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
newSmells
→ List<
String> -
Smells that are new since the baseline snapshot.
final
-
newViolations
→ List<
String> -
Governance violations that are new since the baseline snapshot.
final
-
resolvedSmells
→ List<
String> -
Smells that have been resolved since the baseline snapshot.
final
-
resolvedViolations
→ List<
String> -
Governance violations that have been resolved since the baseline snapshot.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scoreDelta → double
-
Change in Architecture Health Score (positive = improvement).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited