IdeAnalysisReport class
Full diagnostic payload produced by IdeIntelligenceEngine.buildReport.
Serialises to the JSON format consumed by the VS Code companion extension.
Constructors
-
IdeAnalysisReport({required String targetPath, required int totalDiagnostics, required int architectureDiagnosticCount, required int governanceDiagnosticCount, required List<
IdeDiagnostic> diagnostics}) -
Creates an IdeAnalysisReport.
const
Properties
- architectureDiagnosticCount → int
-
Number of diagnostics in the
'architecture'category.final -
diagnostics
→ List<
IdeDiagnostic> -
Flat list of all IdeDiagnostics.
final
- governanceDiagnosticCount → int
-
Number of diagnostics in the
'governance'category.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetPath → String
-
Absolute path to the scanned project directory.
final
- totalDiagnostics → int
-
Total number of diagnostics across all categories.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises this report to the JSON payload consumed by the VS Code extension.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited