migrator/models/graph_models library
Classes
- ArchitectureGraph
- A semantic graph of all detected components and their dependencies.
- DependencyEdge
- A directed relationship between two nodes in the ArchitectureGraph.
Enums
- RelationshipType
- The semantic type of a relationship between two architecture components.