HookWidgetNode class
IR node for a HookWidget that uses flutter_hooks.
- Inheritance
-
- Object
- ProviderNode
- HookWidgetNode
Constructors
- HookWidgetNode({required String widgetName, required int buildMethodOffset, required String filePath, required int offset, required int length})
- Creates a HookWidgetNode.
Properties
- buildMethodOffset → int
-
Source offset of the
build()method.final - filePath → String
-
Absolute path to the source file that contains this node.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Byte length of the node within the source file.
finalinherited
- offset → int
-
Byte offset of the node's start within the source file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetName → String
-
Class name of the hook widget.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited