LogicUnitNode class
IR node for a ChangeNotifier / Bloc / Cubit / GetxController / MobX store.
- Inheritance
-
- Object
- ProviderNode
- LogicUnitNode
Constructors
-
LogicUnitNode({required String name, required List<
FieldInfo> stateFields, required List<MethodInfo> methods, required bool isNotifier, NotifierType notifierType = NotifierType.stateNotifier, bool isFamilyCandidate = false, String role = 'logic', String? superClassName, List<String> mixins = const [], required String filePath, required int offset, required int length}) - Creates a LogicUnitNode.
Properties
- filePath → String
-
Absolute path to the source file that contains this node.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFamilyCandidate → bool
-
True when the class constructor has required parameters.
final
- isNotifier → bool
-
final
- length → int
-
Byte length of the node within the source file.
finalinherited
-
methods
→ List<
MethodInfo> -
final
-
mixins
→ List<
String> -
Names of mixins used by this class.
final
- name → String
-
final
- notifierType → NotifierType
-
Best-fit Riverpod primitive inferred from the class's method signatures.
final
- offset → int
-
Byte offset of the node's start within the source file.
finalinherited
- role → String
-
Semantic architecture role (e.g., 'bloc', 'controller', 'repository', 'service')
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stateFields
→ List<
FieldInfo> -
final
-
stateVariables
→ List<
String> -
Raw field names in declaration order.
no setter
- superClassName → String?
-
Name of the superclass.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises the node to a JSON-compatible map for reports and dashboards.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited