ParamInfo class
A parameter captured from a method declaration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Parameter name as it appears in source.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Dart type of the parameter, defaulting to
'dynamic'when unresolved.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSource(
) → String -
Returns
'type name'— the parameter in source-compatible form. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited