ProviderDeclarationNode class

IR node for an explicit Provider/ChangeNotifierProvider declaration site.

Inheritance

Constructors

ProviderDeclarationNode({required String providerType, required String providedClass, int? childOffset, int? childLength, required String filePath, required int offset, required int length})
Creates a ProviderDeclarationNode.

Properties

childLength int?
Source length of the child: argument, if present.
final
childOffset int?
Source offset of the child: argument, if present.
final
filePath String
Absolute path to the source file that contains this node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
Byte length of the node within the source file.
finalinherited
offset int
Byte offset of the node's start within the source file.
finalinherited
providedClass String
Name of the class being provided, e.g. 'Counter'.
final
providerType String
Provider widget type, e.g. 'ChangeNotifierProvider' or 'BlocProvider'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited