StateNode class

IR node for a State<T> class paired with a StatefulWidget.

Inheritance

Constructors

StateNode({required String stateClassName, required String widgetName, required String filePath, required int offset, required int length})
Creates a StateNode.

Properties

filePath String
Absolute path to the source file that contains this node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
Byte length of the node within the source file.
finalinherited
offset int
Byte offset of the node's start within the source file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateClassName String
Name of the State subclass, e.g. '_HomeScreenState'.
final
widgetName String
Name of the associated StatefulWidget subclass.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited