WidgetNode class

IR node for a StatelessWidget or StatefulWidget class.

Inheritance

Constructors

WidgetNode({required String widgetName, required String widgetType, int? buildMethodOffset, required String filePath, required int offset, required int length})
Creates a WidgetNode.

Properties

buildMethodOffset int?
Source offset of the build() method (or createState() for stateful).
final
filePath String
Absolute path to the source file that contains this node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
Byte length of the node within the source file.
finalinherited
offset int
Byte offset of the node's start within the source file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetName String
Class name of the widget, e.g. 'HomeScreen'.
final
widgetType String
Either 'StatelessWidget' or 'StatefulWidget'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited