migrator/scanner/scanner_utils library
Functions
-
buildMethodInfo(
MethodDeclaration member, {required bool callsNotifyListeners}) → MethodInfo -
Extracts a MethodInfo from
member, recording its return type, body, async flag, getter flag, and formal parameters. -
detectNotifierType(
List< MethodInfo> methods) → NotifierType - Infers the best Riverpod NotifierType based on the methods found in a logic unit.